import React, { Fragment, useState, useEffect, useCallback, createRef, useRef } from 'react';
import { View, Text, Alert, FlatList, StyleSheet, TouchableOpacity } from 'react-native';
import Styled from 'styled-components/native';
import Header from '~/Components/Layouts/Header';
import { Search, SearchIcon, Line, TextInput, checkFilter, filterValue, ListStyle, DetailIcon, RightArrow, CreateButton, SearchTitle } from '~/Components/Listing/Search';
import Checkbox from '~/Components/UIControls/Checkbox';
import Theme from '~/Themes';
import BottomTabBarLayout from '~/Components/Layouts/BottomTabBarLayout';
import session from '~/Utils/session';
import SearchList, { SearchListContainer } from '~/Components/Listing/SearchList';
import EmptyView from '~/Components/Listing/EmptyView';
import EntitySelect from '~/Components/EntitySelect';
import { useToast } from '~/Components/UIControls/Message';
import { DateTimePicker } from '~/Components/UIControls/DateTimePicker';
import Input from '~/Components/UIControls/Input';
import Form from '~/Components/Form';
import { Util } from '~/Utils/utils';
import { useAuth } from '~/Components/Hooks';

// list item
const Item = ({ item, index, onPress = () => { } }) => {
  //console.log(item);
  const zebra = index % 2 === 0 ? true : false;
  const boxColor = item.SiteId === 1 ? "#0b83e6":"#0eb118";
  return (
    <TouchableOpacity onPress={onPress} style={{ ...ListStyle.itemContainer, borderTopWidth: 0, backgroundColor: zebra ? "#fdfdfd" : "#fff" }}>
      <View style={{ ...ListStyle.vertical,width:'100%'}}>
        <View style={{ ...ListStyle.horizon,width:'100%',justifyContent:"space-between"}}>
          <Text style={{ ...ListStyle.rounded}}>
            {Util.get(item, "AccidentTypeName")}
          </Text>
          <Text style={{ ...ListStyle.text,paddingLeft:10,flex:1 }}>
                {Util.get(item, "Name")}
          </Text>
        </View>
        <View style={{ ...ListStyle.horizon,width:'100%',marginTop:10, justifyContent:"space-between"}}>
          <Text style={{ ...ListStyle.textGray, lineHeight: 18 }}>
          {'사고발생일'}
          </Text>
          <Text style={{ ...ListStyle.textGray, textAlign: "left", paddingRight:15, lineHeight: 18  }}>
          {Util.get(item, "Dates.StartDate")}
          </Text>
        </View>
        <View style={{ ...ListStyle.horizon,width:'100%',marginTop:5, justifyContent:"space-between"}}>
          <Text style={{ ...ListStyle.textGray, lineHeight: 18 }}>
          {'조치완료일'}
          </Text>
          <Text style={{ ...ListStyle.textGray, textAlign: "left", paddingRight:15, lineHeight: 18  }}>
          {Util.get(item, "Dates.EndDate")}
          </Text>
        </View>
        <View style={{ ...ListStyle.horizon,width:'100%',marginTop:5, justifyContent:"space-between"}}>
          <Text style={{ ...ListStyle.textGray, lineHeight: 18 }}>
          {'종결일'}
          </Text>
          <Text style={{ ...ListStyle.textGray, textAlign: "left", paddingRight:15, lineHeight: 18  }}>
          {Util.get(item, "Dates.ClosingDate")}
          </Text>
        </View>
      </View>
    </TouchableOpacity>
  )
}

// list and search
const Screen = props => {
  const navigation = props.navigation;
  const [ready, setReady] = useState(false);
  const [filters, setFilters] = useState({});
  const [list, setList] = useState(null);
  const [page, setPage] = useState(1);
  const [refreshing, setRefreshing] = useState(false);
  const pages = useRef(10);
  const { auth } = useAuth(navigation);
  const { showMessage } = useToast();
  console.log('filters : ', filters);

  // load session when mount...
  useEffect(() => {
    (async () => {
      await session.load();
      setReady(true);
    })();
  }, []);

  // search events...
  const start = () => {
    setRefreshing(true);
  };
  const success = (data, append) => {
    pages.current = data.pages;
    
    if (append && page > 1) {
      setList(list.concat(data.list));
    } else {
      setList(data.list);
    }
    setRefreshing(false);
  };
  const fail = e => {
    showMessage(e.message);
    setRefreshing(false);
  };
  const refreshList = () => {
    setPage('refresh-' + Math.random());
}
  //console.log("list", list);

  return ready ? (
    <BottomTabBarLayout>
      <SearchListContainer>
        <SearchList page={page} pages={pages.current} setPage={setPage} refreshing={refreshing}
          data={list} renderItem={({ item, index }) => {
            return (
              <Item item={item} index={index} onPress={() => {
                navigation.navigate('Form', {
                  refreshList: refreshList,
                  action: Form.VIEW,
                  siteId: session.getSiteId(),
                  accidentId: item.AccidentId,
                  auth: auth,
                });
              }} />
            )
          }}
          ListEmptyComponent={<EmptyView list={list} />}
        />
        {auth.Update && <CreateButton onPress={() => {
            navigation.navigate('Form', {
                refreshList: refreshList,
                action: Form.CREATE, 
                siteId: session.getSiteId(), 
                annId: 0,
                auth: auth,
            });
          }} />}
      </SearchListContainer>
      <Search id="accident" api={`api/app/Accident?siteId=${session.getSiteId()}`}
        page={page} limit={10} filters={filters} sort={{field:'AccidentId', order:'desc'}}
        onStart={start} onSuccess={success} onFailure={fail} setPage={setPage} >
 
        <Fragment>
          <SearchTitle title="사고유형" />
          <EntitySelect style={{ marginBottom:5 }} entity="FmsAccidentCodeType"  id="AccidentTypeId" defaultLabel="사고유형" emptyLabel="전체" useCheck={true}
              onChange={(item) => { 
                  filterValue([filters, setFilters], 'AccidentTypeId', item.value, 'eq');
              }} />         
              
          <SearchTitle title="사고명" />
          <Input style={{ marginBottom:20 }} placeholder="사고명" small onChangeText={value => filterValue([filters, setFilters], 'Name', value, 'cn')} />

          <SearchTitle title="사고발생일" />
          <DateTimePicker style={{ marginBottom:10 }} placeholder="시작일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'StartDate', Util.toDateString(newDate) + ' 00:00:00.000', 'ge');}} />                    
          <DateTimePicker style={{ marginBottom:10 }} placeholder="종료일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'StartDate', Util.toDateString(newDate) + ' 23:59:59.998', 'le');}} />                    

          <SearchTitle title="조치완료일" />
          <DateTimePicker style={{ marginBottom:10 }} placeholder="시작일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'EndDate', Util.toDateString(newDate) + ' 00:00:00.000', 'ge');}} />                    
          <DateTimePicker style={{ marginBottom:10 }} placeholder="종료일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'EndDate', Util.toDateString(newDate) + ' 23:59:59.998', 'le');}} />     

          <SearchTitle title="종결일" />
          <DateTimePicker style={{ marginBottom:10 }} placeholder="시작일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'ClosingDate', Util.toDateString(newDate) + ' 00:00:00.000', 'ge');}} />                    
          <DateTimePicker style={{ marginBottom:10 }} placeholder="종료일" useClear={true} onChange={(newDate) => {
                    filterValue([filters, setFilters], 'ClosingDate', Util.toDateString(newDate) + ' 23:59:59.998', 'le');}} />     
        </Fragment>
      </Search>
    </BottomTabBarLayout>
  ) : null;
};

// header
Screen.navigationOptions = ({ navigation }) => {
  return {
    header: () => <Header
      navigation={navigation}
      title="사고관리"
      buttons={<SearchIcon id="accident" />}    />
  }
};

export default Screen;
