import React, { Fragment, useState, useEffect, useCallback, createRef, useRef } from 'react';
import { View, Text, Alert, FlatList, StyleSheet, TouchableOpacity } from 'react-native';
import Styled from 'styled-components/native';
import Header from '~/Components/Layouts/Header';
import { Search, SearchIcon, Line, TextInput, checkFilter, filterValue, ListStyle, DetailIcon, RightArrow, CreateButton, SearchTitle } from '~/Components/Listing/Search';
import Checkbox from '~/Components/UIControls/Checkbox';
import Theme from '~/Themes';
import BottomTabBarLayout from '~/Components/Layouts/BottomTabBarLayout';
import session from '~/Utils/session';
import SearchList from '~/Components/Listing/SearchList';
import EmptyView from '~/Components/Listing/EmptyView';
import EntitySelect from '~/Components/EntitySelect';
import { useToast } from '~/Components/UIControls/Message';
import { DateTimePicker } from '~/Components/UIControls/DateTimePicker';
import Input from '~/Components/UIControls/Input';
import Form from '~/Components/Form';
import Loading from '~/Components/UIControls/Loading';
import { fetchPost } from '~/Utils/fetch';
import PhoneIcon from '~/Assets/Svgs/list_phone.svg';
import { Selectbox } from '~/Components/UIControls/Selectbox';
import { Util } from '~/Utils/utils';
import { useAuth } from '~/Components/Hooks';

// list item
const Item = ({item, siteConfig, index, onPress=()=>{}}) => {
    const zebra = index % 2 == 0 ? true : false;

    return (
        <TouchableOpacity onPress={onPress} style={{
            ...ListStyle.itemContainer, 
            borderTopWidth: 0, 
            backgroundColor: (zebra?'#fdfdfd':'#fff')
        }}>
            <View style={{...ListStyle.vertical, flex:1}}>
                <View style={{...ListStyle.horizon, marginBottom:10}}>
                    <Text style={{...ListStyle.rounded}}>{item.BusinessField.Name}</Text>
                    <Text>&nbsp;&nbsp;</Text>
                    <Text style={{...ListStyle.textMediumLarge}}>{item.Name}</Text>
                </View>
                <View style={{...ListStyle.horizon, width:'100%', paddingRight:15, justifyContent:'space-between'}}>
                    <Text style={{...ListStyle.textLightGray}}>작업예정일</Text>
                    <Text style={{...ListStyle.textLightGray}}>{Util.toDateString(item.WorkDueDate)}</Text>
                </View>
                <View style={{...ListStyle.horizon, width:'100%', paddingRight:15, justifyContent:'space-between'}}>
                    <Text style={{...ListStyle.textLightGray}}>휴일작업</Text>
                    <Text style={{...ListStyle.textLightGray}}>{item.HolidayWorkType.Name}</Text>
                </View>
                <View style={{...ListStyle.horizon, width:'100%', paddingRight:15, justifyContent:'space-between'}}>
                    <Text style={{...ListStyle.textLightGray}}>작업주기</Text>
                    <Text style={{...ListStyle.textLightGray}}>{item.CycleSize}&nbsp;{item.CycleUnit.Name}</Text>
                </View>
                {!siteConfig.UseWorkAutoOrder && 
                <View style={{...ListStyle.horizon, marginTop:10}}>
                    <Checkbox value={item.IsAutoOrder} hasState={false} label="자동지시여부" disabled={true} />
                </View>
                }
            </View>
        </TouchableOpacity>
    )
}

// list and search
const Container = Styled.View`
    flex: 1;
    background-color: #fff;
`;
const Screen = (props) => {
    const navigation = props.navigation;
    const [filters, setFilters] = useState({IsUse_eq:{field:'IsUse',op:'eq',value:true}});
    const [list, setList] = useState(null);
    const [page, setPage] = useState(1);
    const [refreshing, setRefreshing] = useState(false);
    const pages = useRef(10);
    const { auth, userinfo, config } = useAuth(navigation);
    const { showMessage } = useToast();
    const isUseItems = useRef([
        {label:'사용', value:true}, 
        {label:'미사용', value:false}
    ]);

    // search events...
    const start = () => {
        setRefreshing(true);
    }
    const success = async (data, append) => {
        pages.current = data.pages;
        //console.log(data);

        if(append && page > 1) {
            setList(list.concat(data.list));
        } else {
            setList(data.list);
        }
        setRefreshing(false);
    }
    const fail = (e) => {
        showMessage(e.message);
        setRefreshing(false);
    }

    const refreshList = () => {
        setPage('refresh-' + Math.random());
    }

    return (
        <BottomTabBarLayout>
            <Container>
                <SearchList page={page} pages={pages.current} setPage={setPage} refreshing={refreshing}
                    data={list} keyExtractor={item => item.WorkScheduleId+''} renderItem={({ item, index }) => {
                        return (
                            <Item item={item} siteConfig={config} index={index} onPress={() => {
                                navigation.navigate('Form', {
                                    refreshList: refreshList,
                                    action: Form.VIEW, 
                                    siteId: userinfo.SiteId, 
                                    workScheduleId: item.WorkScheduleId, 
                                    workTypeId: item.WorkTypeId,
                                    config: config,
                                    auth: auth,
                                });
                            }} />
                        )
                    }}
                    ListEmptyComponent={<EmptyView list={list} />}
                />
                {auth.Update && (<CreateButton onPress={() => {
                    navigation.navigate('Form', {
                        refreshList: refreshList,
                        action: Form.CREATE, 
                        siteId: userinfo.SiteId, 
                        workScheduleId: 0, 
                        workTypeId: 1,  // 정기점검
                        config: config,
                        auth: auth,
                    });
                }} />)}
            </Container>

            <Search id="regular-work-schedule" api={`api/app/WorkSchedule/RegularList?siteId=${userinfo.SiteId}&businessAuth=${auth.Business}`} 
                    page={page} setPage={setPage} limit={50} filters={filters} sort={{field:'WorkScheduleId', order:'desc'}}
                    onStart={start} onSuccess={success} onFailure={fail} >
                <Fragment>
                    <SearchTitle title="업무분야" />
                    <EntitySelect style={{ marginBottom:20 }} entity="CmBusinessField"
                        defaultLabel="분류1" emptyLabel="전체" useCheck={true} auth={auth}
                        onChange={(item) => { 
                            filterValue([filters, setFilters], 'BusinessFieldId', item.value, 'eq');
                        }} auth={auth} />

                    <SearchTitle title="업무명" />
                    <Input style={{ marginBottom:20 }} placeholder="업무명" small onChangeText={value => filterValue([filters, setFilters], 'Name', value, 'cn')} />

                    <SearchTitle title="작업예정일" />
                    <DateTimePicker style={{ marginBottom:20 }} placeholder="시작일" useClear={true} onChange={(newDate) => {
                        filterValue([filters, setFilters], 'WorkDueDate', newDate, 'ge');
                    }} />
                    <DateTimePicker style={{ marginBottom:20 }} placeholder="종료일" useClear={true} onChange={(newDate) => {
                        filterValue([filters, setFilters], 'WorkDueDate', newDate, 'le');
                    }} />

                    <SearchTitle title="사용여부" />
                    <Selectbox style={{ marginBottom:20 }} initialValue={true} defaultLabel="사용여부" emptyLabel="전체"
                        items={isUseItems.current}
                        onChange={item => {
                            filterValue([filters, setFilters], 'IsUse', item.value, 'eq');
                        }} />

                </Fragment>
            </Search>
        </BottomTabBarLayout> 
    );
};

// header
Screen.navigationOptions = ({navigation}) => { 
    return { 
        header: () => <Header 
            navigation={navigation} 
            title="정기점검 계획" 
            buttons={<SearchIcon id="regular-work-schedule" />}
        /> 
    } 
};

export default Screen;